package org.apache.felix;

import java.util.logging.Level;

import org.apache.felix.framework.Logger;
import org.osgi.framework.Bundle;
import org.osgi.framework.BundleException;
import org.osgi.framework.ServiceReference;

/**
 * @author gaellalire
 */
public class JDKLogger extends Logger {

    public static final java.util.logging.Logger LOGGER = java.util.logging.Logger.getLogger(JDKLogger.class.getName());

    @SuppressWarnings("rawtypes")
    @Override
    protected void doLog(final Bundle bundle, final ServiceReference sr, final int level, final String msg, final Throwable throwable) {
        String s = "";
        if (sr != null) {
            s = s + "SvcRef " + sr + " ";
        } else if (bundle != null) {
            s = s + "Bundle " + bundle.toString() + " ";
        }
        s = s + msg;

        Level jdkLevel;

        switch (level) {
        case LOG_DEBUG:
            jdkLevel = Level.FINE;
            break;
        case LOG_ERROR:
            jdkLevel = Level.SEVERE;
            break;
        case LOG_INFO:
            jdkLevel = Level.INFO;
            break;
        case LOG_WARNING:
            jdkLevel = Level.WARNING;
            break;
        default:
            jdkLevel = Level.WARNING;
            s = "UNKNOWN[" + level + "]: " + s;
        }

        if (throwable != null) {
            Throwable lThrowable = throwable;
            if ((throwable instanceof BundleException) && (((BundleException) throwable).getNestedException() != null)) {
                lThrowable = ((BundleException) throwable).getNestedException();
            }
            LOGGER.log(jdkLevel, s, lThrowable);
        } else {
            LOGGER.log(jdkLevel, s);
        }
    }

}
